==> torch_npu-2.1.0.post12-cp311-cp311-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: torch_npu/contrib/__init__.py <==
from .function import npu_iou, npu_ptiou, npu_giou, npu_diou, npu_ciou, npu_multiclass_nms, \
     npu_batched_multiclass_nms, npu_single_level_responsible_flags, npu_fast_condition_index_put, \
     npu_bbox_coder_encode_yolo, npu_bbox_coder_encode_xyxy2xywh, npu_bbox_coder_decode_xywh2xyxy, \
     roll, matmul_transpose, npu_fused_attention_with_layernorm, npu_fused_attention
from .module import ChannelShuffle, Prefetcher, LabelSmoothingCrossEntropy, ROIAlign, DCNv2, \
     ModulatedDeformConv, Mish, BiLSTM, PSROIPool, SiLU, Swish, NpuFairseqDropout, NpuCachedDropout, \
     MultiheadAttention, FusedColorJitter, NpuDropPath, Focus, FastBatchNorm1d, FastBatchNorm2d, \
     FastBatchNorm3d, FastSyncBatchNorm, LinearA8W8Quant, LinearQuant, LinearWeightQuant, QuantConv2d

__all__ = [
    # from function
    "npu_iou",
    "npu_ptiou",
    "npu_giou",
    "npu_diou",
    "npu_ciou",
    "npu_multiclass_nms",
    "npu_batched_multiclass_nms",
    "npu_single_level_responsible_flags",
    "npu_fast_condition_index_put",
    "npu_bbox_coder_encode_yolo",
    "npu_bbox_coder_encode_xyxy2xywh",
    "npu_bbox_coder_decode_xywh2xyxy",
    "fuse_add_softmax_dropout",
    "roll",
    "matmul_transpose",
    "npu_fused_attention_with_layernorm",
    "npu_fused_attention",

    # from module
    "ChannelShuffle",
    "Prefetcher",
    "LabelSmoothingCrossEntropy",
    "ROIAlign",
    "DCNv2",
    "ModulatedDeformConv",
    "Mish",
    "BiLSTM",
    "PSROIPool",
    "SiLU",
    "Swish",
    "NpuFairseqDropout",
    "NpuCachedDropout",
    "MultiheadAttention",
    "NpuDropPath",
    "Focus",
    "LinearA8W8Quant",
    "LinearQuant",
    "FusedColorJitter",
    "LinearWeightQuant",
    "QuantConv2d",
]

==> torch_npu-2.6.0rc1-cp311-cp311-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: torch_npu/contrib/__init__.py <==
from .function import npu_iou, npu_ptiou, npu_giou, npu_diou, npu_ciou, npu_multiclass_nms, \
     npu_batched_multiclass_nms, npu_single_level_responsible_flags, npu_fast_condition_index_put, \
     npu_bbox_coder_encode_yolo, npu_bbox_coder_encode_xyxy2xywh, npu_bbox_coder_decode_xywh2xyxy, \
     roll, matmul_transpose, npu_fused_attention_with_layernorm, npu_fused_attention
from .module import ChannelShuffle, Prefetcher, LabelSmoothingCrossEntropy, ROIAlign, DCNv2, \
     ModulatedDeformConv, Mish, BiLSTM, PSROIPool, SiLU, Swish, NpuFairseqDropout, NpuCachedDropout, \
     MultiheadAttention, FusedColorJitter, NpuDropPath, Focus, FastBatchNorm1d, FastBatchNorm2d, \
     FastBatchNorm3d, FastSyncBatchNorm, LinearA8W8Quant, LinearQuant, LinearWeightQuant

__all__ = [
    # from function
    "npu_multiclass_nms",
    "npu_batched_multiclass_nms",
    "npu_single_level_responsible_flags",
    "npu_fast_condition_index_put",
    "npu_bbox_coder_encode_yolo",
    "npu_bbox_coder_encode_xyxy2xywh",
    "npu_bbox_coder_decode_xywh2xyxy",
    "fuse_add_softmax_dropout",
    "roll",
    "matmul_transpose",
    "npu_fused_attention_with_layernorm",
    "npu_fused_attention",

    # from module
    "ChannelShuffle",
    "Prefetcher",
    "LabelSmoothingCrossEntropy",
    "ROIAlign",
    "ModulatedDeformConv",
    "PSROIPool",
    "NpuFairseqDropout",
    "NpuCachedDropout",
    "MultiheadAttention",
    "NpuDropPath",
    "Focus",
    "LinearA8W8Quant",
    "LinearQuant",
    "LinearWeightQuant",
]
